pub fn default_absdiff() -> ImPtDetectCfgExpand description
Default configuration for detecting features brighter or darker than background
pub fn default_absdiff() -> ImPtDetectCfgDefault configuration for detecting features brighter or darker than background